'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var index = require('../../../../@csnx/design-tokens/tokens/index.js');

// Arrays of colours should have pillar colors first
// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette)
 *
 * Colour palette organised by type e.g. 'error', or pillar e.g. 'opinion'
 */
const palette = {
    brand: index.tokens.palette.brand,
    brandAlt: index.tokens.palette.brandAlt,
    neutral: index.tokens.palette.neutral,
    error: index.tokens.palette.error,
    success: index.tokens.palette.success,
    news: index.tokens.palette.news,
    opinion: index.tokens.palette.opinion,
    sport: index.tokens.palette.sport,
    culture: index.tokens.palette.culture,
    lifestyle: index.tokens.palette.lifestyle,
    labs: index.tokens.palette.labs,
    specialReport: index.tokens.palette.specialReport,
    specialReportAlt: index.tokens.palette.specialReportAlt,
    focus: index.tokens.palette.focus,
};
// Hover colours are snowflakes as they are manipulations of colours from the
// main palette.
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/9280ee)
 *
 * Default theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
const background = {
    primary: palette.neutral[100],
    secondary: palette.neutral[97],
    inverse: palette.neutral[10],
    ctaPrimary: palette.brand[400],
    ctaPrimaryHover: '#234B8A',
    ctaSecondary: palette.brand[800],
    ctaSecondaryHover: '#ACC9F7',
    ctaTertiaryHover: '#E5E5E5',
    input: palette.neutral[100],
    inputChecked: palette.brand[500],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/63cc10)
 *
 * Brand theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandBackground = {
    primary: palette.brand[400],
    inputChecked: palette.neutral[100],
    ctaPrimary: palette.neutral[100],
    ctaPrimaryHover: '#E0E0E0',
    ctaSecondary: palette.brand[600],
    ctaSecondaryHover: '#234B8A',
    ctaTertiaryHover: palette.brand[300],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/743232)
 *
 * Alternative brand theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltBackground = {
    primary: palette.brandAlt[400],
    ctaPrimary: palette.neutral[7],
    ctaPrimaryHover: '#454545',
    ctaSecondary: palette.brandAlt[200],
    ctaSecondaryHover: '#F2AE00',
    ctaTertiaryHover: '#FFD213',
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/69c92f)
 *
 * Default theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
const border = {
    primary: palette.neutral[60],
    secondary: palette.neutral[86],
    success: palette.success[400],
    error: palette.error[400],
    ctaTertiary: palette.brand[400],
    input: palette.neutral[60],
    inputChecked: palette.brand[500],
    inputHover: palette.brand[500],
    inputActive: palette.brand[500],
    focusHalo: palette.focus[400],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/04883b)
 *
 * Brand theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandBorder = {
    primary: palette.brand[600],
    secondary: palette.brand[600],
    success: palette.success[500],
    error: palette.error[500],
    ctaTertiary: palette.neutral[100],
    input: palette.brand[800],
    inputChecked: palette.neutral[100],
    inputHover: palette.neutral[100],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/b/21c6cc)
 *
 * Alternative brand theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltBorder = {
    ctaTertiary: palette.neutral[7],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/593cc9)
 *
 * Default theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
const line = {
    primary: palette.neutral[86],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/66455d)
 *
 * Brand theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandLine = {
    primary: palette.brand[600],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/89955e)
 *
 * Alternative brand theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltLine = {
    primary: palette.neutral[7],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/85d3b0)
 *
 * Default theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
const text = {
    primary: palette.neutral[7],
    supporting: palette.neutral[46],
    success: palette.success[400],
    error: palette.error[400],
    ctaPrimary: palette.neutral[100],
    ctaSecondary: palette.brand[400],
    ctaTertiary: palette.brand[400],
    anchorPrimary: palette.brand[500],
    anchorSecondary: palette.neutral[7],
    userInput: palette.neutral[7],
    inputLabel: palette.neutral[7],
    inputError: palette.neutral[7],
    inputLabelSupporting: palette.neutral[46],
    inputChecked: palette.brand[400], //choice card only
    inputHover: palette.brand[400], //choice card only
    groupLabel: palette.neutral[7],
    groupLabelSupporting: palette.neutral[46],
    newsInverse: palette.news[550],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/244480)
 *
 * Brand theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandText = {
    primary: palette.neutral[100],
    supporting: palette.brand[800],
    success: palette.success[500],
    error: palette.error[500],
    ctaPrimary: palette.brand[400],
    ctaSecondary: palette.neutral[100],
    ctaTertiary: palette.neutral[100],
    anchorPrimary: palette.neutral[100],
    anchorPrimaryHover: palette.brandAlt[400],
    userInput: palette.neutral[100],
    inputLabel: palette.neutral[100],
    inputLabelSupporting: palette.brand[800],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/11d5fd)
 *
 * Alternative brand theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltText = {
    primary: palette.neutral[7],
    supporting: palette.neutral[60],
    ctaPrimary: palette.neutral[100],
    ctaSecondary: palette.neutral[7],
    ctaTertiary: palette.neutral[7],
    anchorPrimary: palette.neutral[7],
};

exports.background = background;
exports.border = border;
exports.brandAltBackground = brandAltBackground;
exports.brandAltBorder = brandAltBorder;
exports.brandAltLine = brandAltLine;
exports.brandAltText = brandAltText;
exports.brandBackground = brandBackground;
exports.brandBorder = brandBorder;
exports.brandLine = brandLine;
exports.brandText = brandText;
exports.line = line;
exports.palette = palette;
exports.text = text;
//# sourceMappingURL=palette.js.map
